capstone_sys::cs_disasm [] [src]

pub unsafe extern fn cs_disasm(handle: csh, code: *const u8, code_size: size_t, address: u64, count: size_t, insn: *mut *mut cs_insn) -> size_t

Disassemble binary code in context of handle, given the code buffer of size code_size, the base address and the desired number (count) of instructions to decode and set a pointer to an array of instructions and returns the number of decoded instructions and the size of the buffers.

Safety