capstone_sys::cs_errno
[−]
[src]
pub unsafe extern fn cs_errno(handle: csh) -> cs_err
Report the last error number for the given Capstone handle when some API function fail.
Like glibc's errno, cs_errno might not retain its old value once accessed.