capstone_sys::cs_close
[−]
[src]
pub unsafe extern fn cs_close(handle: *mut csh) -> cs_err
Close a Capstone handle (and zeroed it).
Release the handle when it is not used anymore but only when there is no
longer usage of Capstone, in particular no access to cs_insn array.